%bcond_without check

%{!?bash_completions_dir:%global bash_completions_dir %{_datadir}/bash-completion/completions}
%{!?fish_completions_dir:%global fish_completions_dir %{_datadir}/fish/vendor_completions.d}
%{!?zsh_completions_dir:%global zsh_completions_dir %{_datadir}/zsh/site-functions}

Name:           python-maturin
Version:        1.2.3
Release:        %mkrel 1
Summary:        Build and publish Rust crates as Python packages
Group:          Development/Python

%global pypi_version %(echo %{version} | tr -d "~")

License:        MIT OR Apache-2.0
URL:            https://github.com/PyO3/maturin
Source0:        %{pypi_source maturin %{pypi_version}}
Source1:		vendor-maturin.tar.gz
Source2:        cargo_config

# * disable features with missing dependencies:
#   - cli-completion (support for dynamic shell completions)
#   - cross (support for cross compiling with zig / xwin)
#   - upload (support for uploading wheels to PyPI)
# * drop unused test dependencies
Patch0:          0001-disable-unavailable-features-and-drop-unused-test-de.patch

# * drop incompatible arguments from setuptools_rust cargo invocations
Patch1:          0002-drop-incompatible-cargo-flags-from-setuptools_rust.patch

# * drop #!/usr/bin/env python3 shebang from maturin/__init__.py
Patch2:          0003-remove-shebang-from-non-executable-__init__.py-file.patch

BuildRequires:  rust-packaging >= 23
BuildRequires:  python3-devel
BuildRequires:	python3dist(wheel)
BuildRequires:	pyproject-rpm-macros
BuildRequires:  python3dist(tomli)
BuildRequires:  python3dist(pip)

%description
Build and publish crates with pyo3, rust-cpython and cffi bindings as
well as rust binaries as python packages.

%package -n     python3-maturin
Summary:        %{summary}
Provides:       maturin = %{version}-%{release}

%description -n python3-maturin
Build and publish crates with pyo3, rust-cpython and cffi bindings as
well as rust binaries as python packages.

%prep
%autosetup -n maturin-%{pypi_version} -p1
mkdir .cargo
cp %{SOURCE2} .cargo/config
tar -xf %{SOURCE1}
%define cargo_registry %{_builddir}/maturin-%{pypi_version}/vendor
%cargo_prep

%generate_buildrequires
%pyproject_buildrequires

%build
export RUSTFLAGS="%{build_rustflags}"
%pyproject_wheel

# write license summary and breakdown
%{cargo_license_summary}
%{cargo_license} > LICENSE.dependencies

%install
%pyproject_install
%pyproject_save_files maturin

%if %{with check}
%check
# * skip a test for macos
# * skip tests for which fixtures are not included in published sources
%cargo_test -- -- --skip build_options::test::test_find_bridge --skip metadata::test::test_implicit_readme \
--skip metadata::test::test_merge_metadata_from_pyproject \
--skip pyproject_toml::tests::test_warn_missing_maturin_version --skip  build_context::test::test_macosx_deployment_target
%endif

%files -n python3-maturin -f %{pyproject_files}
%license license-apache
%license license-mit
%license LICENSE.dependencies
%doc README.md
%doc Changelog.md

%{_bindir}/maturin


%changelog
* Fri Apr 04 2025 katnatek <katnatek> 1.2.3-1.mga9
+ Revision: 2173358
- Version 1.2.3

* Sun Feb 23 2025 wally <wally> 1.8.2-1.mga10
+ Revision: 2151681
- new version 1.8.2
- rebuild for python3.13

* Fri Dec 29 2023 wally <wally> 1.4.0-5.mga10
+ Revision: 2024007
- build using system rust pkgs

* Thu Dec 28 2023 papoteur <papoteur> 1.4.0-4.mga10
+ Revision: 2023369
- rebuild again for python 3.12

* Sun Dec 10 2023 wally <wally> 1.4.0-3.mga10
+ Revision: 2016909
- rebuild for py3.12

* Wed Dec 06 2023 wally <wally> 1.4.0-2.mga10
+ Revision: 2013568
- provide maturin
- drop extras subpkgs as we don't have python-patchelf nor python-ziglang
- build using %%build_rustflags

* Tue Dec 05 2023 papoteur <papoteur> 1.4.0-1.mga10
+ Revision: 2013362
- imported package python-maturin

